#ifndef _PLX9080REG_H
#define _PLX9080REG_H

/*******************************************************************************
 * Copyright (c) 2001 PLX Technology, Inc.
 * 
 * PLX Technology Inc. licenses this software under specific terms and
 * conditions.  Use of any of the software or derviatives thereof in any
 * product without a PLX Technology chip is strictly prohibited. 
 * 
 * PLX Technology, Inc. provides this software AS IS, WITHOUT ANY WARRANTY,
 * EXPRESS OR IMPLIED, INCLUDING, WITHOUT LIMITATION, ANY WARRANTY OF
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  PLX makes no guarantee
 * or representations regarding the use of, or the results of the use of,
 * the software and documentation in terms of correctness, accuracy,
 * reliability, currentness, or otherwise; and you rely on the software,
 * documentation and results solely at your own risk.
 * 
 * IN NO EVENT SHALL PLX BE LIABLE FOR ANY LOSS OF USE, LOSS OF BUSINESS,
 * LOSS OF PROFITS, INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES
 * OF ANY KIND.  IN NO EVENT SHALL PLX'S TOTAL LIABILITY EXCEED THE SUM
 * PAID TO PLX FOR THE PRODUCT LICENSED HEREUNDER.
 * 
 ******************************************************************************/

/******************************************************************************
 * 
 * File Name:
 *
 *      Reg9080.h
 *
 * Description:
 *
 *      This file defines all the PCI 9080 Registers.
 *
 * Revision:
 *
 *      01-30-01 : PCI SDK v3.20
 *
 ******************************************************************************/


#define CFG_VENDOR_ID           0x000
#define CFG_COMMAND             0x004
#define CFG_REV_ID              0x008
#define CFG_CACHE_SIZE          0x00C
#define CFG_BAR0                0x010
#define CFG_BAR1                0x014
#define CFG_BAR2                0x018
#define CFG_BAR3                0x01C
#define CFG_BAR4                0x020
#define CFG_BAR5                0x024
#define CFG_CIS_PTR             0x028
#define CFG_SUB_VENDOR_ID       0x02C
#define CFG_EXP_ROM_BASE        0x030
#define CFG_CAP_PTR             0x034
#define CFG_RESERVED1           0x038
#define CFG_INT_LINE            0x03C

#ifdef __cplusplus
extern "C" {
#endif

#if defined(IOP_CODE)
    #define PCI9080_REG_BASE    0x080
#elif defined(PCI_CODE)
    #define PCI9080_REG_BASE    0x000
#else
    #error Need to define IOP_CODE or PCI_CODE
#endif


/* PCI Configuration Registers */
#define PCI9080_VENDOR_ID            CFG_VENDOR_ID
#define PCI9080_COMMAND              CFG_COMMAND
#define PCI9080_REV_ID               CFG_REV_ID
#define PCI9080_CACHE_SIZE           CFG_CACHE_SIZE
#define PCI9080_RTR_BASE             CFG_BAR0
#define PCI9080_RTR_IO_BASE          CFG_BAR1
#define PCI9080_LOCAL_BASE0          CFG_BAR2
#define PCI9080_LOCAL_BASE1          CFG_BAR3
#define PCI9080_UNUSED_BASE1         CFG_BAR4
#define PCI9080_UNUSED_BASE2         CFG_BAR5
#define PCI9080_CIS_PTR              CFG_CIS_PTR
#define PCI9080_SUB_ID               CFG_SUB_VENDOR_ID
#define PCI9080_EXP_ROM_BASE         CFG_EXP_ROM_BASE
#define PCI9080_RESERVED1            CFG_CAP_PTR
#define PCI9080_RESERVED2            CFG_RESERVED1
#define PCI9080_INT_LINE             CFG_INT_LINE


/* Local Configuration Registers */
#define PCI9080_SPACE0_RANGE         (PCI9080_REG_BASE + 0x000)
#define PCI9080_SPACE0_REMAP         (PCI9080_REG_BASE + 0x004)
#define PCI9080_LOCAL_DMA_ARBIT      (PCI9080_REG_BASE + 0x008)
#define PCI9080_ENDIAN_DESC          (PCI9080_REG_BASE + 0x00C)
#define PCI9080_EXP_ROM_RANGE        (PCI9080_REG_BASE + 0x010)
#define PCI9080_EXP_ROM_REMAP        (PCI9080_REG_BASE + 0x014)
#define PCI9080_SPACE0_ROM_DESC      (PCI9080_REG_BASE + 0x018)
#define PCI9080_DM_RANGE             (PCI9080_REG_BASE + 0x01C)
#define PCI9080_DM_MEM_BASE          (PCI9080_REG_BASE + 0x020)
#define PCI9080_DM_IO_BASE           (PCI9080_REG_BASE + 0x024)
#define PCI9080_DM_PCI_MEM_REMAP     (PCI9080_REG_BASE + 0x028)
#define PCI9080_DM_PCI_IO_CONFIG     (PCI9080_REG_BASE + 0x02C)
#define PCI9080_SPACE1_RANGE         (PCI9080_REG_BASE + 0x0F0)
#define PCI9080_SPACE1_REMAP         (PCI9080_REG_BASE + 0x0F4)
#define PCI9080_SPACE1_DESC          (PCI9080_REG_BASE + 0x0F8)


/* Runtime Registers */
#if defined(IOP_CODE)
    #define PCI9080_MAILBOX0         0x0C0
    #define PCI9080_MAILBOX1         0x0C4
#elif defined(PCI_CODE)
    #define PCI9080_MAILBOX0         0x078
    #define PCI9080_MAILBOX1         0x07C
#endif

#define PCI9080_MAILBOX2             (PCI9080_REG_BASE + 0x048)
#define PCI9080_MAILBOX3             (PCI9080_REG_BASE + 0x04C)
#define PCI9080_MAILBOX4             (PCI9080_REG_BASE + 0x050)
#define PCI9080_MAILBOX5             (PCI9080_REG_BASE + 0x054)
#define PCI9080_MAILBOX6             (PCI9080_REG_BASE + 0x058)
#define PCI9080_MAILBOX7             (PCI9080_REG_BASE + 0x05C)
#define PCI9080_LOCAL_DOORBELL       (PCI9080_REG_BASE + 0x060)
#define PCI9080_PCI_DOORBELL         (PCI9080_REG_BASE + 0x064)
#define PCI9080_INT_CTRL_STAT        (PCI9080_REG_BASE + 0x068)
#define PCI9080_EEPROM_CTRL_STAT     (PCI9080_REG_BASE + 0x06C)
#define PCI9080_PERM_VENDOR_ID       (PCI9080_REG_BASE + 0x070)
#define PCI9080_REVISION_ID          (PCI9080_REG_BASE + 0x074)


/* DMA Registers */
#define PCI9080_DMA0_MODE            (PCI9080_REG_BASE + 0x080)
#define PCI9080_DMA0_PCI_ADDR        (PCI9080_REG_BASE + 0x084)
#define PCI9080_DMA0_LOCAL_ADDR      (PCI9080_REG_BASE + 0x088)
#define PCI9080_DMA0_COUNT           (PCI9080_REG_BASE + 0x08C)
#define PCI9080_DMA0_DESC_PTR        (PCI9080_REG_BASE + 0x090)
#define PCI9080_DMA1_MODE            (PCI9080_REG_BASE + 0x094)
#define PCI9080_DMA1_PCI_ADDR        (PCI9080_REG_BASE + 0x098)
#define PCI9080_DMA1_LOCAL_ADDR      (PCI9080_REG_BASE + 0x09C)
#define PCI9080_DMA1_COUNT           (PCI9080_REG_BASE + 0x0A0)
#define PCI9080_DMA1_DESC_PTR        (PCI9080_REG_BASE + 0x0A4)
#define PCI9080_DMA0_COMMAND_STAT    (PCI9080_REG_BASE + 0x0A8)
#define PCI9080_DMA_ARBIT            (PCI9080_REG_BASE + 0x0AC)
#define PCI9080_DMA_THRESHOLD        (PCI9080_REG_BASE + 0x0B0)


/* Messaging FIFO Registers */
#define PCI9080_OUTPOST_INT_STAT     (PCI9080_REG_BASE + 0x030)
#define PCI9080_OUTPOST_INT_MASK     (PCI9080_REG_BASE + 0x034)
#define PCI9080_MU_CONFIG            (PCI9080_REG_BASE + 0x0C0)
#define PCI9080_FIFO_BASE_ADDR       (PCI9080_REG_BASE + 0x0C4)
#define PCI9080_INFREE_HEAD_PTR      (PCI9080_REG_BASE + 0x0C8)
#define PCI9080_INFREE_TAIL_PTR      (PCI9080_REG_BASE + 0x0CC)
#define PCI9080_INPOST_HEAD_PTR      (PCI9080_REG_BASE + 0x0D0)
#define PCI9080_INPOST_TAIL_PTR      (PCI9080_REG_BASE + 0x0D4)
#define PCI9080_OUTFREE_HEAD_PTR     (PCI9080_REG_BASE + 0x0D8)
#define PCI9080_OUTFREE_TAIL_PTR     (PCI9080_REG_BASE + 0x0DC)
#define PCI9080_OUTPOST_HEAD_PTR     (PCI9080_REG_BASE + 0x0E0)
#define PCI9080_OUTPOST_TAIL_PTR     (PCI9080_REG_BASE + 0x0E4)
#define PCI9080_FIFO_CTRL_STAT       (PCI9080_REG_BASE + 0x0E8)


/* Additional register defintions */
#if defined(PCI_CODE)
    #define PCI9080_IN_FIFO_PORT     0x040
    #define PCI9080_OUT_FIFO_PORT    0x044
#endif

#define MAX_PCI9080_REG_OFFSET       (PCI9080_REG_BASE + 0x100)


#ifdef __cplusplus
}
#endif

#endif
