/*
 * plxpci.h
 *
 * plxpci driver constants and fileoperations
 * Written by: niko.neufeld@cern.ch CERN/LHCb 2002
 */

/* $Id */

#ifndef __PLXPCI_H_
#define __PLXPCI_H_

#include <linux/kernel.h>
#include <linux/fs.h>
#include <linux/pci.h>
#include <linux/string.h>
#include <linux/sched.h>

#include "plxtypes.h"

#define PLX_MAX_DEVICE 8
#define PLX_MAJOR 0

#define PLX_DEVICE_SET_NAME(s, n) { \
               strcpy(s, "plx"); \
               if (n < 10) { \
                      s[3] = '0' + n; s[4] = 0; \
               } else {  \
                      s[3] = '1'; s[4] = '0' + (n - 10); \
               } \
               s[5] = 0; \
        }
        
	
#ifdef NDEBUG
#define dprintk(x)
#else
#define dprintk(x) printk(KERN_DEBUG "plx:"x)
#endif

/* protos */

unsigned long *find_mem_region(unsigned long *size);
int plx_ioctl(struct inode *, struct file *, unsigned int, unsigned long);
int plx_open(struct inode *, struct file *);
int plx_release(struct inode *, struct file *); 
int plx_probe(void);
int plx_module_int(void);
void plx_module_cleanup(void);


struct plx_dev {
	struct plx_dev    *next;
        struct pci_dev    *pci_dev;
	char              name[6];
	int               plx_type;
	u32               baseaddr[2];
	u32               winsize[2];
	u32               regs;
	struct plx_ops    *ops;
	int               irq;
};

/* functions (maybe) specific to a particular PCI90xx */

struct plx_ops {
	int (*init)(struct plx_dev *);
	int (*init_local_bus)(struct plx_dev *, plx_loc_mem_t *);
	void (*irqh)(int, void *, struct pt_regs *);
	int (*read_local_bus)(struct plx_dev *, plx_loc_data_t *);
	int (*write_local_bus)(struct plx_dev *, plx_loc_data_t *);
	void (*cleanup)(struct plx_dev *);
};	


int plx_init(struct plx_dev *plxp);
int plx_init_local_bus(struct plx_dev *plxp, plx_loc_mem_t *);
int plx_module_init(void);
int plx_write_local_bus(struct plx_dev *dev, struct plx_loc_data *dat);
int plx_read_local_bus(struct plx_dev *dev, struct plx_loc_data *dat);
int plx_write_config_dword(struct plx_dev *, u8 where, u32 value);
int plx_read_config_dword(struct plx_dev *, u8 where, u32 *value);
void plx_irqh(int, void *, struct pt_regs *);
void plx_cleanup(struct plx_dev *);

#endif





