/*
 * plxtest.c test program for plx driver
 *
 * written by: niko.neufeld@cern.ch CERN/LHCb 2002
 *
 */

/* $Id: plxtest.c,v 1.2 2002/10/01 16:17:03 nikolaus Exp $ */

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <errno.h>
#include <linux/types.h>

#include "plxioctl.h"
#include "plxtypes.h"
#include "plx9080reg.h"

#define ALT_NO_COMMAND 0
#define ALT_TEST_MODE  (1 << 24)
#define ALT_START_ACQ  (1 << 25)
#define ALT_RESET_RAM  (1 << 26)

int plx_write_local(int fd, __u32 addr, __u32 val, int width) 
{
     struct plx_loc_data dat;
     int status = 0;

     dat.address = addr;
     dat.data = val;
     dat.flag = width;
     if (ioctl(fd, PLX_WRITE_LOC_BUS, &dat)) {
	  perror("ioctl plx_write_loc_bus");
	  status = -1;
     }
     return status;
}



int plx_read_local(int fd, __u32 addr, __u32 *val, int width)
{
     struct plx_loc_data dat;
     int status = 0;

     dat.address = addr;
     dat.flag = width;
     if (ioctl(fd, PLX_READ_LOC_BUS, &dat)) {
	  perror("ioctl plx_read_loc_bus");
	  status = -1;
     }
     *val = dat.data;
     return status;
}

int plx_read_reg(int fd, __u8 off, __u32 *val)
{
     struct plx_reg reg;
     
     reg.offset = off;
     if (ioctl(fd, PLX_READ_REG, &reg)) {
	  perror("ioctl plx_read_reg");
	  return -1;
     }
     *val = reg.value;
     return 0;
}

void regdump(int fd) {
     int i;
     __u32 val;

     for (i = 0; i < 128; i+=4) {
	  if (!(i % 16)) printf("\n0x%02x: ", i);
	  if (!plx_read_reg(fd, i, &val)) {
	       printf("%08x ", val);
	  } else {
	       printf("???????? ");
	  }
     }
     printf("\n");
}

void memdump(int fd, unsigned long from, unsigned long range) 
{
     unsigned long i, j;
     __u32 value;

     for (j = 0, i = from; i < from + range; ++j, i+=4) {
	  if (!(j % 8)) {
	       printf("\n0x%08lx ", i);
	  }
	  if (!plx_read_local(fd, i, &value, PLX_DATA_WIDTH_DWORD)) {
	       printf("%08x ", value);
	  } else {
	       printf("???????? ");
	  }
     }
     printf("\n");
}

void memdumpb(int fd, unsigned long from, unsigned long range) 
{
     unsigned long i, j;
     __u32 value;

     for (j = 0, i = from; i < from + range; ++j, ++i) {
	  if (!(j % 16)) {
	       printf("\n0x%08lx ", i);
	  }
	  if (!plx_read_local(fd, i, &value, PLX_DATA_WIDTH_BYTE)) {
	       printf("%02x ", value);
	  } else {
	       printf("?? ");
	  }
     }
     printf("\n");
}

int main(int argc, char **argv) 
{
     int fd, status = 0;
     plx_loc_mem_t locmem;
     __u32 val;

     if ((fd = open("/dev/plx0", O_RDWR)) == -1) {
	  perror("open");
	  exit(1);
     }
     
     regdump(fd);

     locmem.address_mask =  0xf0000000;
     locmem.address_start = 0x0;
     locmem.base_address =  0xe0000000;
      
     
     if (ioctl(fd, PLX_INIT_LOC_BUS, &locmem)) {
	  perror("ioctl plx_init_loc_bus");
	  status = 1;
	  exit(errno);
     }
     printf("mask 0x%08x address 0x%08x base 0x%08x\n",
	    locmem.address_mask, locmem.address_start, locmem.base_address);
     regdump(fd); 


     memdump(fd, 0x0, 0x100);
     
     printf("Starting acquisition\n");
     plx_read_local(fd, ALT_START_ACQ, &val, PLX_DATA_WIDTH_DWORD);
     printf("read 0x%08x\n", val);     
     sleep(1);
     memdump(fd, 0x0, 0x100);

     printf("Resetting RAM\n");
     plx_read_local(fd, ALT_RESET_RAM, &val, PLX_DATA_WIDTH_DWORD);
     printf("read 0x%08x\n", val);     
     memdump(fd, 0x0, 0x100);
     sleep(1);

#if 0
     memdumpb(fd, 0x0, 0x100);
     { 
	  __u32 val;
	  plx_read_local(fd, 0x0, &val, PLX_DATA_WIDTH_DWORD);
	  printf("unaligned read %08x\n", val);
     }
     close(fd);
#endif
     exit(status);
}












